<!--
SPDX-FileCopyrightText: Nir Soffer <nirsof@gail.com>
SPDX-License-Identifier: MIT
-->

# Look ma no hands!

A little library for effortless demos.

![Example demo](https://i.imgur.com/dhQkaVj.gif)

To run the example demo:

    python example.py

## License

This work is licensed under MIT license. See `LICENSES/MIT.txt` for more
info.
